@@ -28,11 +28,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.7
+Version v3.0.8
 
 =cut
 
-our $VERSION = version->declare("v3.0.7");
+our $VERSION = version->declare("v3.0.8");
 
 =head1 SYNOPSIS
 
@@ -109,15 +109,13 @@ my $default_ignore_regex = q!
 my $copyright_indicator_regex = qr!
 	(?:copyright(?:-holders?)? # The full word (or slightly more)
 		|copr\. # Legally-valid abbreviation
-		|\xc2\xa9 # Unicode copyright sign encoded in iso8859
-		|\x{00a9} # Unicode character COPYRIGHT SIGN
-		#|© # Unicode character COPYRIGHT SIGN
+		|© # Unicode character COPYRIGHT SIGN
 		|\(c\) # Legally-null representation of sign
 	)
-!lix;
+!ix;
 
 my $copyright_indicator_regex_with_capture
-	= qr!$copyright_indicator_regex(?::\s*|\s+)(\S.*)$!lix;
+	= qr!$copyright_indicator_regex(?::\s*|\s+)(\S.*)$!ix;
 
 # avoid ditching things like <info@foo.com>
 my $copyright_disindicator_regex = qr{
@@ -269,7 +267,7 @@ sub parse_file
 
 	return (
 		$self->parse_license( clean_cruft_and_spaces($cleaned_content) ),
-		extract_copyright($cleaned_content),
+		extract_copyright( clean_cruft($cleaned_content) ),
 	);
 }
 
@@ -304,7 +302,7 @@ sub parse_lines
 
 	my $license
 		= $self->parse_license( clean_cruft_and_spaces($cleaned_content) );
-	my $copyrights = extract_copyright($cleaned_content);
+	my $copyrights = extract_copyright( clean_cruft($cleaned_content) );
 
 	if ( not @$copyrights and $license eq 'UNKNOWN' ) {
 		my $position = $fh->tell;                 # See IO::Seekable
@@ -321,7 +319,7 @@ sub parse_lines
 
 		my $cleaned_tail = clean_comments($tail);
 
-		$copyrights = extract_copyright($cleaned_tail);
+		$copyrights = extract_copyright( clean_cruft($cleaned_tail) );
 		$license
 			= $self->parse_license( clean_cruft_and_spaces($cleaned_tail) );
 	}
@@ -384,8 +382,6 @@ sub parse_copyright
 				$match =~ s/\s*\bby\b\s*/ /;
 				$match =~ s/([,.])?\s*$//;
 				$match =~ s/\s{2,}/ /g;
-				$match =~ s/\\//g;    # de-cruft nroff files
-				$match =~ s/\s*[*#]\s*$//;
 				$copyright = $match;
 			}
 		}
@@ -415,6 +411,9 @@ sub clean_comments
 		s/^$comment_re//mg;
 	}
 
+	# Remove other side of "boxed" comments
+	s/\s*[*#]\s*$//gm;
+
 	# Remove Fortran comments
 	s/^[cC] //gm;
 
@@ -424,6 +423,20 @@ sub clean_comments
 	return $_;
 }
 
+sub clean_cruft
+{
+	local $_ = shift or return q{};
+
+	# TODO: decode latin1/UTF-8/HTML data instead
+	s/\xcb\x97|\xe2\x80[\x90-\x95|\xe2\x81\x83|\xe2\x88\x92|\xef\x89\xa3|\xef\xbc\x8d]|[&](?:ndash|mdash|horbar|minus|[#](?:727|820[8-9]|821[0-3]|8259|8722|65123|65293|x727|z201[0-5]|x2043|x2212|xFE63|xFF0D))[;]/-/gm;
+	s/\x58\xa9|\xc2\xa9|\xe2\x92\x9e|\xe2\x92\xb8|\xe2\x93\x92|\xf0\x9f\x84\x92|\xf0\x9f\x84\xab|\xf0\x9f\x85\x92|[&](?:copy|[#](?:169|9374|9400|9426|127250|127275|127314|x0A9|x249E|x24b8|x24D2|x0F112|x0F12B|x0F152))[;]/©/gm;
+
+	# TODO: decode nroff files specifically instead
+	s/\\//gm;    # de-cruft nroff files
+
+	return $_;
+}
+
 sub clean_cruft_and_spaces
 {
 	local $_ = shift or return q{};
@@ -505,7 +518,7 @@ sub parse_license
 		when ( /unless such copies or derivative works are solely in the form of machine-executable object code generated by a source language processor/ ) {
 			break;
 		}
-		when ( /(All changes made in this file will be lost|DO NOT ((?:HAND )?EDIT|delete this file|modify)|edit the original|Generated (automatically|by|from|data)|generated.*file)/i ) {
+		when ( /(All changes made in this file will be lost|DO NOT ((?:HAND )?EDIT|delete this file|modify)|edit the original|Generated (automatically|by|from|data|with)|generated.*file)/i ) {
 			$license = "GENERATED FILE";
 			push @spdx_license, 'generated-file';
 		}
